# Introduction

**Dexpo** is a simple CLI tool for generating basic reports about a given python package's reputation and known vulnerabilites using data from the [PyPI](https://warehouse.pypa.io/api-reference/) and [GitHub](https://docs.github.com/en/rest) APIs.

# Requirements

- Python >= 3.11

# Getting Started

1. Install dexpo `pip install dexpo`

# Usage

```console
$ dexpo pandas
```
![example](https://github.com/jackboy2fly/dexpo/assets/81083035/62bc80a8-0fa7-468f-8515-0af622e42dc2)
